# ✨ awesome-panel-extensions

⚠️ The extensions in this package are currently being carved out and split into seperate
extensions. Please check out the
[awesome-panel repositories](https://github.com/orgs/awesome-panel/repositories) to see if the
extension you need is available there.

We want to

- Make sure [Panel](https://panel.holoviz.org/) has lots of available extensions

We provide

- The `awesome-panel-extensions` Python package containing extra extensions for Panel.

You can install and use the package as simple as.

```bash
pip install awesome-panel-extensions
```

## 🚀 Get started in under a minute

Install `awesome-panel-extensions` including the *`examples` dependencies*.

```bash
pip install  awesome-panel-extensions[examples]
```

Explore the sample apps

```bash
pn hello  awesome-panel-extensions
```

![Project Intro](https://raw.githubusercontent.com/awesome-panel/awesome-panel-extensions/main/assets/videos/pn-hello-awesome-panel-extensions.gif)

You can now find the *reference* and *gallery* notebooks in the `examples/awesome-panel/awesome-panel-extensions` folder. Check them out by running `jupyter lab`.

## 📒 Explore the examples online

Click one of the buttons

[![nbviewer](https://raw.githubusercontent.com/jupyter/design/master/logos/Badges/nbviewer_badge.svg)](https://nbviewer.org/github/awesome-panel/awesome-panel-extensions/tree/main/examples/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/awesome-panel/awesome-panel-extensions/HEAD)

## ⭐ Support

Please support [Panel](https://panel.holoviz.org) and
[awesome-panel](https://awesome-panel.org) by giving the projects a star on Github:

- [holoviz/panel](https://github.com/holoviz/panel).
- [awesome-panel/awesome-panel](https://github.com/awesome-panel/awesome-panel).

Thanks

## ❤️ Contribute

If you are looking to contribute to this project you can find ideas in the [issue tracker](https://github.com/awesome-panel/awesome-panel-extensions/issues). To get started check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md).

I would love to support and receive your contributions. Thanks.

[![Hacktober Fest](https://github.blog/wp-content/uploads/2022/10/hacktoberfestbanner.jpeg?fit=1200%2C630)](https://github.com/awesome-panel/awesome-panel-extensions/issues).

## Monitor

[![PyPI version](https://badge.fury.io/py/panel-highcharts.svg)](https://pypi.org/project/awesome-panel-extensions/)
[![Downloads](https://pepy.tech/badge/panel-highcharts/month)](https://pepy.tech/project/awesome-panel-extensions)
![Python Versions](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-blue)
[![License](https://img.shields.io/badge/License-MIT%202.0-blue.svg)](https://opensource.org/licenses/MIT)
![Test Results](https://github.com/awesome-panel/awesome-panel-extensions/actions/workflows/tests.yaml/badge.svg?branch=main)